Check whether a schema exists for the current dialect
Source:R/Dialect-mssql.R, R/Dialect-mysql.R, R/Dialect-postgres.R, and 2 more
check_schema_exists.RdDialects that do not implement schemas should return TRUE.
Usage
check_schema_exists.mssql(x, .schema)
check_schema_exists.mysql(x, .schema)
check_schema_exists.postgres(x, .schema)
check_schema_exists(x, .schema)
check_schema_exists.default(x, .schema)
check_schema_exists.sqlite(x, .schema)Functions
check_schema_exists.mssql(): Check if a schema exists for SQL Server.check_schema_exists.mysql(): Check if a schema exists for MySQL.check_schema_exists.postgres(): Check if a schema exists for PostgreSQL.check_schema_exists.sqlite(): SQLite does not support schemas; always returns TRUE